@@ -331,6 +331,7 @@ int changepars(void)
 	    break;
 	}
     case 19:			/* EXIT */
+    case 38:			/* QUIT */
 	{
 	    writeparas();
 	    clear();
@@ -552,15 +553,6 @@ int changepars(void)
 	    break;
 	}
 
-    case 38:			/* EXIT=QUIT */
-	{
-	    writeparas();
-	    cleanup_telnet();
-	    endwin();
-	    puts("\n\nThanks for using TLF.. 73\n");
-	    exit(0);
-	    break;
-	}
     case 39:			/* CQDELAY */
 	{
 	    mvprintw(12, 29, "CQD: pgup/dwn", cqdelay);
@@ -571,7 +563,10 @@ int changepars(void)
 		x = key_get();
 
 		switch (x) {
-		case 156:{
+
+		// <Page-Up>, increase autoCQ delay by 1/2 second.
+		case KEY_PPAGE:
+		    {
 			if (cqdelay <= 60) {
 			    cqdelay++;
 			    attron(COLOR_PAIR(C_HEADER) | A_STANDOUT);
@@ -581,7 +576,10 @@ int changepars(void)
 
 			}
 		    }
-		case 157:{
+
+		// <Page-Down>, decrease autoCQ delay by 1/2 second.
+		case KEY_NPAGE:
+		    {
 			if (cqdelay >= 1) {
 			    cqdelay--;
 			    attron(COLOR_PAIR(C_HEADER) | A_STANDOUT);
@@ -649,13 +647,18 @@ int changepars(void)
 		x = key_get();
 
 		switch (x) {
-		case 156:{
+
+		// <Page-Up>, increase volume by 5%.
+		case KEY_PPAGE:
+		    {
 			if (volumebuffer < 95)
 			    volumebuffer += 5;
 
 			break;
 		    }
-		case 157:{
+		// <Page-Down>, decrease volume by 5%.
+		case KEY_NPAGE:
+		    {
 			if (volumebuffer >= 5)
 			    volumebuffer -= 5;
 
