@@ -2,7 +2,7 @@
  * Tlf - contest logging program for amateur radio operators
  * Copyright (C) 2001-2002-2003 Rein Couperus <pa0r@eudxf.org>
  *                    2010-2014 Thomas Beierlein <tb@forth-ev.de>
- *                    2013-2014 Ervin Hegedus - HA2OS <airween@gmail.com>
+ *                    2013-2016 Ervin Hegedus - HA2OS <airween@gmail.com>
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -97,7 +97,6 @@ int tlfcolors[8][2] = { {COLOR_BLACK, COLOR_WHITE},
 int debugflag = 0;
 int editor = EDITOR_JOE;
 char rttyoutput[120];
-int use_vk = 0;
 int tune_val = 0;
 int use_bandoutput = 0;
 int no_arrows = 0;
@@ -335,6 +334,8 @@ char rigconf[80];
 int in_packetclient;
 int tnc_serial_rate = 2400;
 char clusterlogin[80] = "";
+int bmautoadd = 0;
+int bmautograb = 0;
 
 /*-------------------------------------rigctl-------------------------------*/
 #ifdef HAVE_LIBHAMLIB
@@ -529,6 +530,20 @@ void ui_init()
     } else
 	putenv("TERM=rxvt");	/*or going to native console linux driver */
 
+    /* Check the environment variable ESCDELAY.
+     *
+     * If unset set it to 25 mS which should allow enough time to capture
+     * escaped key codes and yet be fast enough to call stoptx() when needed
+     * by the user.  When unset Ncurses assumes a default value of 1000 mS so
+     * use set_escdelay(0) to set it as the Ncurses documentation declares this
+     * method to be thread safe.
+     *
+     * Else let Ncurses honor the user defined value of the env variable.
+     */
+    if (getenv("ESCDELAY") == NULL) {
+	set_escdelay(25);
+    }
+
     /* activate ncurses terminal control */
     if ((mainscreen = newterm(NULL, stdout, stdin)) == NULL) {
 	perror("initscr");
@@ -570,10 +585,11 @@ void ui_init()
     refreshp();
 
     noecho();
-    crmode();
+    cbreak();
 
-//keypad(stdscr,TRUE);
+    keypad(stdscr,TRUE);
 
+    lookup_keys();
 }
 
 
@@ -826,6 +842,14 @@ void tlf_cleanup()
     else
 	deinit_controller();
 
+#ifdef HAVE_LIBHAMLIB
+
+    if (my_rig) {
+	close_tlf_rig(my_rig);
+    }
+
+#endif
+
     endwin();
     tcsetattr( STDIN_FILENO, TCSANOW, &oldt);
 }
