@@ -22,13 +22,18 @@
 	 *              Read country data  from disk file cty.dat
 	 *--------------------------------------------------------------*/
 
-#include "readctydata.h"
-#include "tlf.h"
-#include "dxcc.h"
+
+#include <stdio.h>
+#include <stdlib.h>
+#include <string.h>
+#include <unistd.h>
+
 #include <glib.h>
-#ifdef HAVE_CONFIG_H
-#	include <config.h>
-#endif
+
+#include "dxcc.h"
+#include "tlf.h"
+#include "tlf_curses.h"
+
 
 int readctydata(void)
 {
