@@ -16,13 +16,18 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  */
-#include "write_keyer.h"
-#include "tlf.h"
-#include <assert.h>
+
+
+#include <stdio.h>
+#include <stdlib.h>
+#include <string.h>
+#include <unistd.h>
+
 #include "clear_display.h"
-#include "cwkeyer.h"
 #include "netkeyer.h"
-#include "cw_utils.h"
+#include "tlf.h"
+#include "tlf_curses.h"
+
 
 int write_keyer(void)
 {
